@@ -36,7 +36,10 @@ from barman.lockfile import ConfigUpdateLock
 
 if sys.version_info.major < 3:
     from argparse import Action, _SubParsersAction, _ActionsContainer
-import argcomplete
+try:
+    import argcomplete
+except ImportError:
+    argcomplete = None
 from collections import OrderedDict
 from contextlib import closing
 
@@ -1991,9 +1994,10 @@ def global_config(args):
 
     # Load additional configuration files
     config.load_configuration_files_directory()
-    config.load_config_file(
-        "%s/.barman.auto.conf" % config.get("barman", "barman_home")
-    )
+    # Handle the autoconf file, load it only if exists
+    autoconf_path = "%s/.barman.auto.conf" % config.get("barman", "barman_home")
+    if os.path.exists(autoconf_path):
+        config.load_config_file(autoconf_path)
     # We must validate the configuration here in order to have
     # both output and logging configured
     config.validate_global_config()
@@ -2381,7 +2385,8 @@ def main():
     """
     # noinspection PyBroadException
     try:
-        argcomplete.autocomplete(p)
+        if argcomplete:
+            argcomplete.autocomplete(p)
         args = p.parse_args()
         global_config(args)
         if args.command is None:
