@@ -383,7 +383,6 @@ class ConsoleOutputWriter(object):
     SERVER_OUTPUT_PREFIX = "Server %s:"
 
     def __init__(self, debug=False, quiet=False):
-
         """
         Default output writer that output everything on console.
 
@@ -796,10 +795,11 @@ class ConsoleOutputWriter(object):
         """
         output_fun(header_row.format("Base backup information"))
         if backup_info["size"] is not None:
-            disk_usage_output = "{} ({} with WALs)".format(
-                pretty_size(backup_info["size"]),
-                pretty_size(backup_info["size"] + backup_info["wal_size"]),
-            )
+            disk_usage_output = "{}".format(pretty_size(backup_info["size"]))
+            if "wal_size" in backup_info and backup_info["wal_size"] is not None:
+                disk_usage_output += " ({} with WALs)".format(
+                    pretty_size(backup_info["size"] + backup_info["wal_size"]),
+                )
             output_fun(nested_row.format("Disk usage", disk_usage_output))
         if backup_info["deduplicated_size"] is not None and backup_info["size"] > 0:
             deduplication_ratio = 1 - (
@@ -1642,11 +1642,11 @@ class JsonOutputWriter(ConsoleOutputWriter):
                     percent=data["wal_until_next_compression_ratio"]
                 )
             if data["children_timelines"]:
-                wal_output[
-                    "_WARNING"
-                ] = "WAL information is inaccurate \
+                wal_output["_WARNING"] = (
+                    "WAL information is inaccurate \
                     due to multiple timelines interacting with \
                     this backup"
+                )
                 for history in data["children_timelines"]:
                     wal_output["timelines"].append(str(history.tli))
 
